==> jquery-lte-1.0.3.tgz: package/src/self/methods/move.js <==
import {states, cord, isElement} from "../../utils/lib.js";

export default (_, { el, movepoint, onMove, onMoving, onMoved }) => {
    el = _(el);
    let mousedown = false;
    const call = (fn, e) => typeof fn === 'function' && fn(e);
    let x, y, ol, ot, dx, dy;
    let _pos = side => {
        let st = el.getStyle(side);
        return Number(st.substring(0, st.length - 2))
    };
    el.style({ zIndex: ++states.zIindex }).on('mousedown touchstart', () => el.style({ zIndex: ++states.zIindex }));
    if (!movepoint)
        movepoint = el;
    if (isElement(movepoint)){
        movepoint = _(movepoint);
    }
    movepoint
        .style({ cursor: 'move' })
        .on('mousedown touchstart', e => {
            mousedown = true;
            let c = cord(e);
            x = c.x;
            y = c.y;
            ol = _pos('left');
            ot = _pos('top');
            call(onMove, e)
        })
        .on('mouseleave mouseup touchend', e => {
            mousedown = false;
            if ((dx && Math.abs(dx) > 0) || (dy && Math.abs(dy) > 0))
                call(onMoved);
            x = undefined;
            y = undefined;
            dx = undefined;
            dy = undefined;
        })
        .on('mousemove touchmove', e => {
            e.preventDefault();
            let c = cord(e);
            dx = c.x - x;
            dy = c.y - y;
            if (mousedown) {
                el.style({
                    top: (ot + dy) + 'px',
                    left: (ol + dx) + 'px',
                })
                call(onMoving, e)
            }
        })
    return el;
}

==> jquery-lte-1.1.3.tgz: package/src/self/methods/move.js <==
import {states, cord, isElement} from "../../utils/lib.js";

export default (_, { el, movepoint, onMove, onMoving, onMoved }) => {
    el = _(el);
    let mousedown = false;
    const call = (fn, e) => typeof fn === 'function' && fn(e);
    let x, y, ol, ot, dx, dy;
    let _pos = side => {
        let st = el.getStyle(side);
        return Number(st.substring(0, st.length - 2))
    };
    el.style({ zIndex: ++states.zIindex }).on('mousedown touchstart', () => el.style({ zIndex: ++states.zIindex }));
    if (!movepoint)
        movepoint = el;
    if (isElement(movepoint)){
        movepoint = _(movepoint);
    }
    movepoint
        .style({ cursor: 'move' })
        .on('mousedown touchstart', e => {
            mousedown = true;
            let c = cord(e);
            x = c.x;
            y = c.y;
            ol = _pos('left');
            ot = _pos('top');
            call(onMove, e)
        })
        .on('mouseleave mouseup touchend', () => {
            mousedown = false;
            if ((dx && Math.abs(dx) > 0) || (dy && Math.abs(dy) > 0))
                call(onMoved);
            x = undefined;
            y = undefined;
            dx = undefined;
            dy = undefined;
        })
        .on('mousemove touchmove', e => {
            e.preventDefault()
            let c = cord(e);
            dx = c.x - x;
            dy = c.y - y;
            if (mousedown) {
                el.style({
                    top: (ot + dy) + 'px',
                    left: (ol + dx) + 'px',
                })
                call(onMoving, e)
            }
        })
    return el;
}
